#!/bin/sh
#
# mails.sh
#   
# 05.04.2005  robspr
#
# using: netcat (nc)       - included in busybox or seperate binary
#        tuxwetter-plugin  - for showing text-files with paging
#        shellexec         - to build a menu with mail-headers
#
# prepare:  /var/httpd     - directory for web-interface
#           /var/httpd/tmp - link to /tmp  (ln -s /tmp tmp)
#
# add to shellexec.conf:
#    MENU=Mails
#    ACTION=&*Mails holen,/var/plugins/mails.sh PLUGIN,Mailheader verarbeiten.
#    INCLUDE=/tmp/fm-mails
#    ENDMENU
#

. /var/tuxbox/config/tuxmail/tuxmail.conf

# ---------------------------------------
# some configurations
#
# maximum number of lines for one email
MAXLINES="50"
# maximum mails per box
MAXMAILS="10"
# scan for "Status" to detect end of email header
# if 0 we read the header, count the lines and than read the whole mail
HEADERSCAN="1"
# if scanning for header-end define the maximum number of lines of the header
DEFHEADERLEN="30"


# mailbox and mailboxindex
MAILIDX="0"
MAILBOX="0"

# ---
# refresh menus
# ---
refresh()
{
  rm /tmp/fm-mails >/dev/null 2>&1
  rm /tmp/pop* >/dev/null 2>&1
}

# ---
# read params from tuxmail.conf
# ---
set_mail_params()
{
  case "$MAILBOX" in
    0)
      NAME=$USER0
      PASS=$PASS0
      SERVER=$HOST0
      DISPNAME=$NAME0
    ;;
    1)
      NAME=$USER1
      PASS=$PASS1
      SERVER=$HOST1
      DISPNAME=$NAME1
    ;;
    2)
      NAME=$USER2
      PASS=$PASS2
      SERVER=$HOST2
      DISPNAME=$NAME2
    ;;
    3)
      NAME=$USER3
      PASS=$PASS3
      SERVER=$HOST3
      DISPNAME=$NAME3
    ;;
    4)
      NAME=$USER4
      PASS=$PASS4
      SERVER=$HOST4
      DISPNAME=$NAME4
    ;;
    5)
      NAME=$USER5
      PASS=$PASS5
      SERVER=$HOST5
      DISPNAME=$NAME5
    ;;
    6)
      NAME=$USER6
      PASS=$PASS6
      SERVER=$HOST6
      DISPNAME=$NAME6
    ;;
    7)
      NAME=$USER7
      PASS=$PASS7
      SERVER=$HOST7
      DISPNAME=$NAME7
    ;;
    8)
      NAME=$USER8
      PASS=$PASS8
      SERVER=$HOST8
      DISPNAME=$NAME8
    ;;
    9)
      NAME=$USER9
      PASS=$PASS9
      SERVER=$HOST9
      DISPNAME=$NAME
    ;;
  esac
}

# ---
# read specific mail to file
# ---
read_mail()
{
  # count number of header lines
  H="0"
  if [ "$HEADERSCAN" != "1" ] ; then
    (echo user $NAME;echo pass $PASS;echo top $MAILIDX 0;echo quit) |
    nc $SERVER 110 > /tmp/popmail2
    while read LINE
    do 
      H=`expr "$H" "+" 1`
    done < /tmp/popmail2
    H=`expr "$H" "-" 4`
    MLINES=`expr "$H" "+" "$MAXLINES"`
  else
    MLINES=`expr "$MAXLINES" "+" "$DEFHEADERLEN"`
  fi	

  rm /tmp/popmail
  (echo user $NAME;echo pass $PASS;echo top $MAILIDX $MLINES;echo quit) |
  nc $SERVER 110 > /tmp/popmail1

  N=0
  while read LINE
  do 
    if [ "$HEADERSCAN" = "1" ] ; then
      if [ "$H" = "0" ] ; then
        TESTSTATUS=`expr substr "$LINE" "1" "6"`
        test "$TESTSTATUS" = "Status" && H="1"
      else
        echo "$LINE" >> /tmp/popmail
      fi
      echo "$N" "$H" "$TESTSTATUS"
    else    
      test $N -gt $H && echo "$LINE" >> /tmp/popmail
      N=`expr "$N" "+" 1`
    fi
  done < /tmp/popmail1
}

# ---
# add menu-line to read mail
# ---
add_menuline()
{
  INFO=`expr substr "$LINE" "25" "30"`
  echo "ACTION=&($INFO) for $DISPNAME, /var/plugins/mails.sh SHOW $MAILBOX $MAILIDX" >> /tmp/fm-mails
}

# ---
# the read command using tuxwetter-plugin
# ---
execute_mail()
{
  read_mail
  /var/plugins/tuxwet/tuxwetter "TXTPLAIN=mail,http://127.0.0.1/tmp/popmail"
}

# ---
# generate mailbox entry for one mailbox
# ---
extract_box()
{
  echo "MENU=$DISPNAME,Mails for $DISPNAME" >> /tmp/fm-mails
  I=0
  E=0
  N="-1"
  while [ "$E" != "$N" ]
  do 
    read LINE
    if [ "$I" = "0" ] ; then
      L=${#LINE}
      L=`expr "$L" "-" 2`
      N=`expr substr "$LINE" "$L" 3`
      I=1
      E=`expr "$N" "-" "$MAXMAILS"`
    else
      MAILIDX=$N
      add_menuline $LINE
      N=`expr "$N" "-" 1`
    fi
  done < /tmp/tuxmail.$MAILBOX
  echo "ENDMENU" >> /tmp/fm-mails
}

# ---
# scan through all mailboxes to generate menu-entries
# ---
extract()
{
  MB=0
  while [ "$MB" != "10" ]
  do
    MAILBOX=$MB
    set_mail_params
    test "$NAME" != "" && extract_box
    MB=`expr "$MB" "+" 1`
  done
}

# ---
# parsing command-line
# ---

case "$1" in
  "SHOW")
    MAILBOX="$2"
    MAILIDX="$3"
    set_mail_params
    execute_mail
    ;;
  "PLUGIN")
    refresh
    extract
    ;;
  *)
      echo "usage: mails.sh [SHOW]|[PLUGIN]"
    ;;  
esac

exit 0


